#
# U-popcon-fishing.R, 14 Jul 24
#
# Data from:
# Impact of Installation Counts on Perceived Quality: A Case Study on Debian
# Israel Herraiz and Emad Shihab and Thanh H. D. Nguyen and Ahmed E. Hassan
# Ubuntu data from: https://web.archive.org/web/20110717131607/http://popcon.ubuntu.com/


library("colorspace")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


upc=read.csv("all-results_2012-11-04.csv") # Ubuntu popularity counts
udd=read.csv("Q1_udd.csv.xz", as.is=TRUE)  # Debian install/fault counts

plot(udd$insts, udd$bugs, log="xy", col=pal_col[2],
        xlab="Installs", ylab="Fault reports")

t=glm(log(bugs) ~ log(insts), data=udd)
# t=glm(bugs ~ log(insts), data=udd, family=poisson)
q=predict(t, newdata=data.frame(insts=1:200000), type="response", se.fit=TRUE)
lines(exp(q$fit), col=pal_col[1])
#lines(q$fit, col=pal_col[1])
#lines(exp(q$fit+1.96*q$se.fit), col="blue")
#lines(exp(q$fit-1.96*q$se.fit), col="blue")

# t=loess(log(bugs) ~ insts, data=udd, span=0.2)
# q=predict(t, newdata=data.frame(insts=1:200000))
# # plot(udd$insts, udd$bugs, log="y")
# lines(exp(q), col=pal_col[2])


# Ubuntu

plot(upc$old+upc$vote, upc$vote/(upc$vote+upc$old), log="xy", col=pal_col[2],
	xlab="Installs", ylab="Regular users (fraction of installs)")

dev.copy(dev=png, file="Ureguse-frac.png")
dev.off()


# Merge datasets
upc_dd=merge(upc, udd, by.x="name", by.y="source")
upc_dd$frac_inst=ceiling(upc_dd$insts*upc_dd$vote/(upc_dd$vote+upc_dd$old))


# Various attempt at modelling usage vs fault counts
# plot(upc_dd$frac_inst, upc_dd$bugs, log="xy", col=pal_col[2],
#         xlab="Regular users (estimated)", ylab="Fault reports")

plot(upc_dd$vote, upc_dd$bugs, log="xy", col=pal_col[2],
        xlab="Regular users", ylab="Fault reports")

reg_mod=glm(log(bugs) ~ log(vote), data=upc_dd, subset=(frac_inst > 0))
# t=glm(bugs ~ log(insts), data=udd, family=poisson)
q=predict(reg_mod, newdata=data.frame(vote=1:200000), type="response", se.fit=TRUE)
lines(exp(q$fit), col=pal_col[1])


dev.copy(dev=png, file="faults_reg-user.png")
dev.off()

